==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/RegistrationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder
import com.pulumi.azurenative.desktopvirtualization.kotlin.enums.RegistrationTokenOperation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a RegistrationInfo definition.
 * @property expirationTime Expiration time of registration token.
 * @property registrationTokenOperation The type of resetting the token.
 * @property token The registration token base64 encoded string.
 */
public data class RegistrationInfoArgs(
    public val expirationTime: Output<String>? = null,
    public val registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null,
    public val token: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder()
            .expirationTime(expirationTime?.applyValue({ args0 -> args0 }))
            .registrationTokenOperation(
                registrationTokenOperation?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .token(token?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RegistrationInfoArgs].
 */
@PulumiTagMarker
public class RegistrationInfoArgsBuilder internal constructor() {
    private var expirationTime: Output<String>? = null

    private var registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null

    private var token: Output<String>? = null

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("cvaermnmnvkqbeut")
    public suspend fun expirationTime(`value`: Output<String>) {
        this.expirationTime = value
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("iyhotrmlocfiuuth")
    public suspend
    fun registrationTokenOperation(`value`: Output<Either<String, RegistrationTokenOperation>>) {
        this.registrationTokenOperation = value
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("fsoalhsakibjkavt")
    public suspend fun token(`value`: Output<String>) {
        this.token = value
    }

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("orthsvpylaefxkrt")
    public suspend fun expirationTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expirationTime = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("fvxjewitqbqdwtha")
    public suspend
    fun registrationTokenOperation(`value`: Either<String, RegistrationTokenOperation>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("tmitftrjxuqickdb")
    public fun registrationTokenOperation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("suvibwasrumtlntr")
    public fun registrationTokenOperation(`value`: RegistrationTokenOperation) {
        val toBeMapped = Either.ofRight<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("aetxaaiqpkjsjvhu")
    public suspend fun token(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.token = mapped
    }

    internal fun build(): RegistrationInfoArgs = RegistrationInfoArgs(
        expirationTime = expirationTime,
        registrationTokenOperation = registrationTokenOperation,
        token = token,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/RegistrationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder
import com.pulumi.azurenative.desktopvirtualization.kotlin.enums.RegistrationTokenOperation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a RegistrationInfo definition.
 * @property expirationTime Expiration time of registration token.
 * @property registrationTokenOperation The type of resetting the token.
 * @property token The registration token base64 encoded string.
 */
public data class RegistrationInfoArgs(
    public val expirationTime: Output<String>? = null,
    public val registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null,
    public val token: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.RegistrationInfoArgs.builder()
            .expirationTime(expirationTime?.applyValue({ args0 -> args0 }))
            .registrationTokenOperation(
                registrationTokenOperation?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .token(token?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RegistrationInfoArgs].
 */
@PulumiTagMarker
public class RegistrationInfoArgsBuilder internal constructor() {
    private var expirationTime: Output<String>? = null

    private var registrationTokenOperation: Output<Either<String, RegistrationTokenOperation>>? = null

    private var token: Output<String>? = null

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("bfrathesxwsvjkbr")
    public suspend fun expirationTime(`value`: Output<String>) {
        this.expirationTime = value
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("ynocdrjcxgkblnqr")
    public suspend
    fun registrationTokenOperation(`value`: Output<Either<String, RegistrationTokenOperation>>) {
        this.registrationTokenOperation = value
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("bukrsvceqkucgpvv")
    public suspend fun token(`value`: Output<String>) {
        this.token = value
    }

    /**
     * @param value Expiration time of registration token.
     */
    @JvmName("ccsiocggjtjlphhu")
    public suspend fun expirationTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expirationTime = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("jobdwyftqsmybgxi")
    public suspend
    fun registrationTokenOperation(`value`: Either<String, RegistrationTokenOperation>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("ticjkharjdhdmqhb")
    public fun registrationTokenOperation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The type of resetting the token.
     */
    @JvmName("xbtnoqsrekoifdde")
    public fun registrationTokenOperation(`value`: RegistrationTokenOperation) {
        val toBeMapped = Either.ofRight<String, RegistrationTokenOperation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registrationTokenOperation = mapped
    }

    /**
     * @param value The registration token base64 encoded string.
     */
    @JvmName("lrkjweoegcrudgnr")
    public suspend fun token(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.token = mapped
    }

    internal fun build(): RegistrationInfoArgs = RegistrationInfoArgs(
        expirationTime = expirationTime,
        registrationTokenOperation = registrationTokenOperation,
        token = token,
    )
}
